@@ -36,7 +36,13 @@ class StepBuilder(object):
         self, title: str, required: bool = False, id: str = None, suggestions: List[str] = None
     ):
         return self.add_block(
-            {"type": "textField", "title": title, "required": required, "id": id,}
+            {
+                "type": "textField",
+                "title": title,
+                "required": required,
+                "id": id,
+                "suggestions": suggestions,
+            }
         )
 
     def add_image_field(self, title: str, required: bool = False, id: str = None):
